leaftools.fuse_tied_leaves_in_components_once_by_prolated_durations_without_overhang
====================================================================================

.. autofunction:: abjad.tools.leaftools.fuse_tied_leaves_in_components_once_by_prolated_durations_without_overhang.fuse_tied_leaves_in_components_once_by_prolated_durations_without_overhang
